
/**
 * @file        hv_cal_Mailbox.c
 * @brief       hv_cal_Mailbox source file.
 * @details     This file provides the following functions: \n
 * @author      HiView SoC Software Team
 * @version     1.0.0
 * @date        2022-09-06
 * @copyright   Copyright(c),2022-8, Hiview Software. All rights reserved.
 * @par         History:
 * <table>
 * <tr><th>Author                        <th>Date         <th>Change Description
 * <tr><td>HiView SoC Software Team      <td>2022-09-06   <td>cystereate
 * </table>
*/
#ifndef __HV_CAL_MAILBOX_H__
#define __HV_CAL_MAILBOX_H__

#include "Common/hv_comm_DataType.h"

VOID Hv_Cal_Mailbox_RecvMsgHeader(VOID *pvMsgHeader);
VOID Hv_Cal_Mailbox_RecvMsgBody(VOID *pvMsgBody);
VOID Hv_Cal_Mailbox_RecvMsgFinish(VOID);
VOID Hv_Cal_Mailbox_SendMsgHeader(VOID *pvMsgHeader);
VOID Hv_Cal_Mailbox_SendMsgBody(VOID *pvMsgBody);
VOID Hv_Cal_Mailbox_GetSendStatus(VOID *pvMsg);
VOID Hv_Cal_Mailbox_EnableInterrupt(VOID);
UINT32 Hv_Cal_Mailbox_GetPQToolCmdPort(VOID);
VOID Hv_Cal_Mailbox_ClearSwIntStatus(UINT32 uiSwintStatus);
UINT32 Hv_Cal_Mailbox_GetSwIntStatus(VOID);

#endif /**< __HV_CAL_MAILBOX_H__ */
